'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = scale;

var _d = require('d3');

var _d2 = _interopRequireDefault(_d);

var _d3Scale = require('d3-scale');

var D3Scale = _interopRequireWildcard(_d3Scale);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _mkScaleSettings(props, func) {
	var type = props.type;
	var range = props.range;
	var domain = props.domain;
	var scale = props.scale;
	var bandPaddingInner = props.bandPaddingInner;
	var bandPaddingOuter = props.bandPaddingOuter;


	if (range) func.range(range);
	if (domain) func.domain(domain);

	if (scale === 'band') {

		func.round(true);

		if (bandPaddingInner) {
			func.paddingInner(bandPaddingInner);
		} else {
			func.paddingInner(.1);
		}

		if (bandPaddingOuter) {
			func.paddingOuter(bandPaddingOuter);
		} else {
			func.paddingOuter(.1);
		}
	}

	return func;
}

function scale(props) {

	var _scale = props.scale;

	var func = void 0;

	if (_scale === 'linear') {
		func = D3Scale.scaleLinear();
	} else if (_scale === 'identity') {
		func = D3Scale.scaleIdentity();
	} else if (_scale === 'sqrt') {
		func = D3Scale.scaleSqrt();
	} else if (_scale === 'pow') {
		func = D3Scale.scalePow();
	} else if (_scale === 'log') {
		func = D3Scale.scaleLog();
	} else if (_scale === 'quantize') {
		func = D3Scale.scaleQuantize();
	} else if (_scale === 'quantile') {
		func = D3Scale.scaleQuantile();
	} else if (_scale === 'ordinal') {
		func = D3Scale.scaleOrdinal();
	} else if (_scale === 'time') {
		func = D3Scale.scaleTime();
	} else if (_scale === 'band') {
		func = D3Scale.scaleBand();
	} else {
		var error = new Error('Please check your axis scale setting. "' + _scale + '" scale is invalid.');
		return error;
	}

	func = _mkScaleSettings(props, func);

	return func;
}